diff --git a/lib/private/memcache/memcached.php b/lib/private/memcache/memcached.php
index 978e6c2eff12b398beead40859e2eb87a2367e10..13b1867231ad8ed6aa1522f83858299fa81b9b2f 100644
--- a/lib/private/memcache/memcached.php
+++ b/lib/private/memcache/memcached.php
@@ -18,8 +18,8 @@ class Memcached extends Cache {
 		parent::__construct($prefix);
 		if (is_null(self::$cache)) {
 			self::$cache = new \Memcached();
-			list($host, $port) = \OC_Config::getValue('memcached_server', array('localhost', 11211));
-			self::$cache->addServer($host, $port);
+			$servers = \OC_Config::getValue('memcached_servers', array(array('localhost', 11211)));
+			self::$cache->addServers($servers);
 		}
 	}
diff --git a/config/config.sample.php b/config/config.sample.php
index 1070ef72eda34815e6ed116f11f5fa4737ff4c9c..67152accc3b5ff41fb18453a7f74f5d2952be789 100755
--- a/config/config.sample.php
+++ b/config/config.sample.php
@@ -114,8 +114,14 @@ $CONFIG = array(
 /* Password to use for sendmail mail, depends on mail_smtpauth if this is used */
 "mail_smtppassword" => "",
 
-/* memcached hostname and port (Only used when xCache, APC and APCu are absent.) */
-"memcached_server" => array('localhost', 11211),
+/* memcached servers (Only used when xCache, APC and APCu are absent.) */
+"memcached_servers" => array(
+	// hostname, port and optional weight. Also see:
+	// http://www.php.net/manual/en/memcached.addservers.php
+	// http://www.php.net/manual/en/memcached.addserver.php
+	array('localhost', 11211),
+	//array('other.host.local', 11211),
+),
 
 /* How long should ownCloud keep deleted files in the trash bin, default value:  30 days */
 'trashbin_retention_obligation' => 30,